@@ -671,7 +671,7 @@ describe('AppComponent', () => {
 
       it('should restrain scrolling inside the ToC container', () => {
         const restrainScrolling = spyOn(component, 'restrainScrolling');
-        const evt = new MouseEvent('mousewheel');
+        const evt = new WheelEvent('mousewheel');
 
         setHasFloatingToc(true);
         expect(restrainScrolling).not.toHaveBeenCalled();
@@ -822,101 +822,104 @@ describe('AppComponent', () => {
       it('should redirect to `docs` if deployment mode is `archive` and not at a docs page', () => {
         createTestingModule('guide/aot-compiler', 'archive');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('tutorial', 'archive');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('tutorial/toh-pt1', 'archive');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('docs', 'archive');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('api', 'archive');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('api/core/getPlatform', 'archive');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
       });
 
       it('should not redirect if deployment mode is `next`', () => {
         createTestingModule('', 'next');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('resources', 'next');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('guide/aot-compiler', 'next');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('tutorial', 'next');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('tutorial/toh-pt1', 'next');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('docs', 'next');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('api', 'next');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('api/core/getPlatform', 'next');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
       });
 
       it('should not redirect to `docs` if deployment mode is `stable`', () => {
         createTestingModule('', 'stable');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('resources', 'stable');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('guide/aot-compiler', 'stable');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('tutorial', 'stable');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('tutorial/toh-pt1', 'stable');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('docs', 'stable');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('api', 'stable');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
 
         createTestingModule('api/core/getPlatform', 'stable');
         initializeTest(false);
-        expect(TestBed.get(LocationService).replace).not.toHaveBeenCalled();
+        expect(TestBed.inject(LocationService).replace).not.toHaveBeenCalled();
       });
     });
   });
 
   describe('with mocked DocViewer', () => {
-    const getDocViewer = () => fixture.debugElement.query(By.css('aio-doc-viewer'));
+    const getDocViewer = () => {
+      const docViewer = fixture.debugElement.query(By.css('aio-doc-viewer'));
+      return docViewer;
+    };
     const triggerDocViewerEvent =
         (evt: 'docReady' | 'docRemoved' | 'docInserted' | 'docRendered') =>
           getDocViewer().triggerEventHandler(evt, undefined);
