@@ -33,17 +33,17 @@ describe('multicast', () => {
 
     const connectable = of(1, 2, 3, 4).pipe(multicast(new Subject<number>())) as ConnectableObservable<number>;
 
-    connectable.subscribe(
-      (x) => {
+    connectable.subscribe({
+      next: (x) => {
         expect(x).to.equal(expected.shift());
       },
-      () => {
+      error: () => {
         done(new Error('should not be called'));
       },
-      () => {
+      complete: () => {
         done();
-      }
-    );
+      },
+    });
 
     connectable.connect();
   });
@@ -75,7 +75,7 @@ describe('multicast', () => {
           },
         })
       )
-      .subscribe(null, done, done);
+      .subscribe({ error: done, complete: done });
   });
 
   it('should accept Subject factory functions', (done) => {
@@ -83,17 +83,17 @@ describe('multicast', () => {
 
     const connectable = of(1, 2, 3, 4).pipe(multicast(() => new Subject<number>())) as ConnectableObservable<number>;
 
-    connectable.subscribe(
-      (x) => {
+    connectable.subscribe({
+      next: (x) => {
         expect(x).to.equal(expected.shift());
       },
-      () => {
+      error: () => {
         done(new Error('should not be called'));
       },
-      () => {
+      complete: () => {
         done();
-      }
-    );
+      },
+    });
 
     connectable.connect();
   });
@@ -751,25 +751,23 @@ describe('multicast', () => {
 
       const source = of(1, 2, 3, 4).pipe(multicast(() => new Subject<number>())) as ConnectableObservable<number>;
 
-      source.subscribe(
-        (x) => {
+      source.subscribe({
+        next: (x) => {
           expect(x).to.equal(expected[i++]);
         },
-        null,
-        () => {
+        complete: () => {
           i = 0;
 
-          source.subscribe(
-            (x) => {
+          source.subscribe({
+            next: (x) => {
               expect(x).to.equal(expected[i++]);
             },
-            null,
-            done
-          );
+            complete: done,
+          });
 
           source.connect();
-        }
-      );
+        },
+      });
 
       source.connect();
     });
@@ -784,18 +782,18 @@ describe('multicast', () => {
 
       of('a', 'b', 'c')
         .pipe(switchMap((letter) => source.pipe(map((n) => String(letter + n)))))
-        .subscribe(
-          (x) => {
+        .subscribe({
+          next: (x) => {
             expect(x).to.equal(expected.shift());
           },
-          () => {
+          error: () => {
             done(new Error('should not be called'));
           },
-          () => {
+          complete: () => {
             expect(expected.length).to.equal(0);
             done();
-          }
-        );
+          },
+        });
     });
   });
 
@@ -807,18 +805,18 @@ describe('multicast', () => {
 
       of('a', 'b', 'c')
         .pipe(switchMap((letter) => source.pipe(map((n) => String(letter + n)))))
-        .subscribe(
-          (x) => {
+        .subscribe({
+          next: (x) => {
             expect(x).to.equal(expected.shift());
           },
-          () => {
+          error: () => {
             done(new Error('should not be called'));
           },
-          () => {
+          complete: () => {
             expect(expected.length).to.equal(0);
             done();
-          }
-        );
+          },
+        });
     });
   });
 });
